<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Command;

use Dedi\SyliusStockHistoryPlugin\Service\InventoryLogEntriesRemoverInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

class ClearInventoryLogEntriesCommand extends Command
{
    private SymfonyStyle $io;

    public function __construct(
        private readonly InventoryLogEntriesRemoverInterface $inventoryLogEntriesRemover,
    ) {
        parent::__construct();
    }

    public function configure(): void
    {
        $this
            ->addArgument('days', InputArgument::REQUIRED, 'Number of days ago');
    }

    protected function initialize(InputInterface $input, OutputInterface $output): void
    {
        $this->io = new SymfonyStyle($input, $output);
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $days = filter_var($input->getArgument('days'), \FILTER_VALIDATE_INT, ['options' => ['min_range' => 1]]);
        if (false === $days) {
            $this->io->error('Number of days must be an integer greater than 0');

            return Command::FAILURE;
        }

        if ($input->isInteractive()) {
            $confirmation = $this->io->confirm(sprintf(
                'Are you sure you want to clear the stock movement history from before %s days ago?',
                $days,
            ), false);

            if (false === $confirmation) {
                return Command::INVALID;
            }
        }

        $this->inventoryLogEntriesRemover->remove($days);

        $this->io->success('Inventory log entries have been removed');

        return Command::SUCCESS;
    }

    public static function getDefaultName(): ?string
    {
        return 'dedi:stock-history:clear';
    }

    public static function getDefaultDescription(): ?string
    {
        return 'Clear inventory log entries older than a given number of days';
    }
}
