<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Context;

use Dedi\SyliusStockHistoryPlugin\Enum\InventoryLogEntryType;
use Traversable;

class InventoryLogContextRegistry implements InventoryLogContextRegistryInterface
{
    /** @var InventoryLogContextInterface[] */
    private array $contexts;

    public function __construct(iterable $contexts)
    {
        $this->contexts = $contexts instanceof Traversable ? iterator_to_array($contexts) : $contexts;
    }

    public function get(string $type): InventoryLogContextInterface
    {
        if (!array_key_exists($type, $this->contexts)) {
            throw new \InvalidArgumentException(sprintf('Unrecognized Context identifier %s', $type));
        }

        return $this->contexts[$type];
    }

    public function getAll(): iterable
    {
        return $this->contexts;
    }

    public function getContextForRoute(string $route): InventoryLogContextInterface
    {
        foreach ($this->contexts as $context) {
            if (in_array($route, $context->getRoutes(), true)) {
                return $context;
            }
        }

        return $this->contexts[InventoryLogEntryType::DEFAULT->value];
    }
}
