<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Service;

use DateTimeImmutable;
use Dedi\SyliusStockHistoryPlugin\Entity\InventoryLogEntryInterface;
use Dedi\SyliusStockHistoryPlugin\Repository\InventoryLogEntryRepositoryInterface;
use Doctrine\ORM\EntityManagerInterface;
use Psr\Log\LoggerInterface;

class InventoryLogEntriesRemover implements InventoryLogEntriesRemoverInterface
{
    public function __construct(
        private readonly InventoryLogEntryRepositoryInterface $inventoryLogEntryRepository,
        private readonly EntityManagerInterface $entityManager,
        private readonly LoggerInterface $logger,
        private readonly int $batchSize = 100,
    ) {
    }

    public function remove(int $days): void
    {
        $fromDate = new DateTimeImmutable(sprintf('%d days ago', $days));

        while ([] !== $inventoryLogEntries = $this->inventoryLogEntryRepository->findOlderThan($fromDate, $this->batchSize)) {
            /** @var InventoryLogEntryInterface $inventoryLogEntry */
            foreach ($inventoryLogEntries as $inventoryLogEntry) {
                try {
                    $this->inventoryLogEntryRepository->remove($inventoryLogEntry);
                } catch (\Exception $e) {
                    $this->logger->error($e);
                }
            }

            try {
                $this->entityManager->flush();
                $this->entityManager->clear();
            } catch (\Exception $e) {
                $this->logger->error($e);
            }
        }
    }
}
